/*******************************************************************************
 *	@file			DL.cpp
 *	@brief			DirectX Library
 *
 *	@date			08-Apr-2009(Wed)
 ******************************************************************************/

// vvZbT---------------------------------------------------------------
#include "DL.h"
#include "DLGraph.h"
#include "DLSound.h"

#include "DLDebug.h"

/*******************************************************************************
 *	@namespace	DL
 ******************************************************************************/
namespace	DL
{

// O[oϐ---------------------------------------------------------
CDLGraph			g_CGraph;													//!< DirectX Graphics
CDLSound			g_CSound;													//!< DirectX Sound

CDLDebug			g_CDebug;

// ֐vg^Cv錾---------------------------------------------------

// -----------------------------------------------------------------------------
/*******************************************************************************
 *	@fn				int LoadGraph( const SDLMaterial& SDL )
 *	@param[in]		SDL							fޏ\
 *	@retval			int							fޔԍ
 *	@brief			fޓǂݍ݁iDirectX Graphicsj
 ******************************************************************************/
int LoadGraph( const SDLMaterial& SDL )
{
	return g_CGraph.Load( SDL );
}

/*******************************************************************************
 *	@fn				int RemoveGraph( const SDLMaterial& SDL )
 *	@param[in]		SDL							fޏ\
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			fމiDirectX Graphicsj
 ******************************************************************************/
int RemoveGraph( const SDLMaterial& SDL )
{
	return g_CGraph.Remove( SDL );
}

// -----------------------------------------------------------------------------
// o[֐|C^ifޓǂݍ݁j
int ( *StepLoad[ enumMaterial_Max ] )( const SDLMaterial& SDL ) =
{
	NULL,
	&LoadGraph, &LoadGraph,
	&LoadGraph,
};
// o[֐|C^ifމj
int ( *StepRemove[ enumMaterial_Max ] )( const SDLMaterial& SDL ) =
{
	NULL,
	&RemoveGraph, &RemoveGraph,
	&RemoveGraph,
};

/*******************************************************************************
 *	@fn				int Init( const SDLParam& SDL,
 *							  const SDLDebug& SDbg )
 *	@param[in]		SDL							\
 *	@param[in]		SDbg						fobO\
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			DirectX ̏
 ******************************************************************************/
int Init( const SDLParam& SDL,
		  const SDLDebug& SDbg )
{
	// COM̏
	::CoInitialize( NULL );
	// DLGraph̏
	if( !g_CGraph.Init( SDL ) ) return FALSE;
	// DLSound̏
	if( !g_CSound.Init( SDL ) ) return FALSE;

	// DLDebug̏
	if( !g_CDebug.Init( SDbg ) ) return FALSE;

	return TRUE;
}

/*******************************************************************************
 *	@fn				int Exit( void )
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			DirectX ̏I
 ******************************************************************************/
int Exit( void )
{
	// DLDebug̏I
	g_CDebug.End();


	// DLSound̏I
	g_CSound.End();
	// DLGraph̏I
	g_CGraph.End();
	// COM̉
	::CoUninitialize();

	return TRUE;
}

/*******************************************************************************
 *	@fn				int Exec( void )
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			DirectX ̎s
 ******************************************************************************/
int Exec( void )
{
	// \[g
	g_CGraph.Sort();
	// ʍXV
	g_CGraph.Update();

	return TRUE;
}

/*******************************************************************************
 *	@fn				int Load( const SDLMaterial& SDL )
 *	@param[in]		SDL							fޏ\
 *	@retval			int							fޔԍ
 *	@brief			fޓǂݍ
 ******************************************************************************/
int Load( const SDLMaterial& SDL )
{
	return ( *StepLoad[ SDL.m_eMat ] )( SDL );
}

/*******************************************************************************
 *	@fn				int Remove( const SDLMaterial& SDL )
 *	@param[in]		SDL							fޏ\
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			fމ
 ******************************************************************************/
int Remove( const SDLMaterial& SDL )
{
	return ( *StepRemove[ SDL.m_eMat ] )( SDL );
}

/*******************************************************************************
 *	@fn				void Clear( void )
 *	@retval			none
 *	@brief			NA
 ******************************************************************************/
void Clear( void )
{
	g_CDebug.Clear();
}

/*******************************************************************************
 *	@fn				float Measurement( void )
 *	@retval			float						fTime
 *	@brief			
 ******************************************************************************/
float Measurement( void )
{
	return g_CDebug.Measurement();
}

/*******************************************************************************
 *	@fn				int ChangeDisplay( const SDLParam& SDL )
 *	@param[in]		SDL							\
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			ʐ؂ւ
 ******************************************************************************/
int ChangeDisplay( const SDLParam& SDL )
{
	return g_CGraph.ChangeDisplay( SDL );
}

/*******************************************************************************
 *	@fn				void* GetGraphics( void )
 *	@retval			void*						TRUE=OK/FALSE=NG
 *	@brief			GraphicsNX擾
 ******************************************************************************/
void* GetGraphics( void )
{
	return static_cast<void*>( &g_CGraph );
}

/*******************************************************************************
 *	@fn				int Add( const SDLGraph& SDL )
 *	@param[in]		SDL							IuWFNg\
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			IuWFNgǉ
 ******************************************************************************/
int Add( const SDLGraph& SDL )
{
	return g_CGraph.Add( SDL );
}

/*******************************************************************************
 *	@fn				int Del( const SDLGraph& SDL )
 *	@param[in]		SDL							IuWFNg\
 *	@retval			int							TRUE=OK/FALSE=NG
 *	@brief			IuWFNg폜
 ******************************************************************************/
int Del( const SDLGraph& SDL )
{
	return g_CGraph.Del( SDL );
}

}	// namespace	DL
